intelmq.bots.parsers.ci_army package — intelmq 2.3.3.alpha1 documentation

# intelmq.bots.parsers.ci_army package

## Submodules

## intelmq.bots.parsers.ci_army.parser module

`intelmq.bots.parsers.ci_army.parser.` `BOT`

  alias of `intelmq.bots.parsers.ci_army.parser.CIArmyParserBot`

class `intelmq.bots.parsers.ci_army.parser.` `CIArmyParserBot`(bot_id: str, start: bool = False, sighup_event=None, disable_multithreading: Optional[bool] = None)

  Bases: `intelmq.lib.bot.Bot`

  `process`()

## Module contents